Struct WpSinglePixelBufferManagerV1
pub struct WpSinglePixelBufferManagerV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
global factory for single-pixel buffers
The wp_single_pixel_buffer_manager_v1 interface is a factory for single-pixel buffers.
This interface has no events.
Implementations
impl WpSinglePixelBufferManagerV1
impl WpSinglePixelBufferManagerV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the manager
Destroy the wp_single_pixel_buffer_manager_v1 object.
The child objects created via this interface are unaffected.
pub fn create_u32_rgba_buffer<U, D>(
&self,
r: u32,
g: u32,
b: u32,
a: u32,
qh: &QueueHandle<D>,
udata: U,
) -> WlBuffer
pub fn create_u32_rgba_buffer<U, D>( &self, r: u32, g: u32, b: u32, a: u32, qh: &QueueHandle<D>, udata: U, ) -> WlBuffer
create a 1×1 buffer from 32-bit RGBA values
Create a single-pixel buffer from four 32-bit RGBA values.
Unless specified in another protocol extension, the RGBA values use pre-multiplied alpha.
The width and height of the buffer are 1.
The r, g, b and a arguments valid range is from UINT32_MIN (0) to UINT32_MAX (0xffffffff).
These arguments should be interpreted as a percentage, i.e.
- UINT32_MIN = 0% of the given color component
- UINT32_MAX = 100% of the given color component